@@ -29,16 +29,18 @@ object PathsResolver {
   val sparkSystemVersion = System.getProperty("datafu.spark.version")
   
   val py4js = Map(
-      "2.2.0" -> "0.10.7",
-      "2.2.1" -> "0.10.7",
       "2.2.2" -> "0.10.7",
-      "2.3.0" -> "0.10.6",
+      "2.2.3" -> "0.10.8.1",
       "2.3.1" -> "0.10.7",
       "2.3.2" -> "0.10.7",
+      "2.3.3" -> "0.10.8.1",
+      "2.3.4" -> "0.10.8.1",
       "2.4.0" -> "0.10.8.1",
       "2.4.1" -> "0.10.8.1",
       "2.4.2" -> "0.10.8.1",
-      "2.4.3" -> "0.10.8.1"
+      "2.4.3" -> "0.10.8.1",
+      "2.4.4" -> "0.10.8.1",
+      "2.4.5" -> "0.10.8.1"
   )
 
   val sparkVersion = if (sparkSystemVersion == null) "2.4.3" else sparkSystemVersion
